netapp_ontap.models.raid_group API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.raid_group`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class RaidGroupSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the RaidGroup object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `cache_tier GET`

    RAID group is a cache tier

  `degraded GET`

    RAID group is degraded. A RAID group is degraded when at least one disk from that group has failed or is offline.

  `disks GET`

    The disks field of the raid_group.

  `name GET`

    RAID group name

    Example: rg0

  `recomputing_parity GET`

    The recomputing_parity field of the raid_group.

  `reconstruct GET`

    The reconstruct field of the raid_group.